==> org.eclipse.papyrusrt.umlrt.tooling.diagram.common.source_0.9.0.201704060416.jar: org/eclipse/papyrusrt/umlrt/tooling/diagram/common/internal/editpolicies/stereotype/RTAppliedStereotypeEditPolicyProvider.java <==
/*****************************************************************************
 * Copyright (c) 2016 Christian W. Damus and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Christian W. Damus - Initial API and implementation
 *   
 *****************************************************************************/

package org.eclipse.papyrusrt.umlrt.tooling.diagram.common.internal.editpolicies.stereotype;

import static org.eclipse.papyrus.uml.diagram.stereotype.edition.editpolicies.AppliedStereotypeCommentEditPolicy.APPLIED_STEREOTYPE_COMMENT;

import java.util.Map;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gmf.runtime.common.core.service.AbstractProvider;
import org.eclipse.gmf.runtime.common.core.service.IOperation;
import org.eclipse.gmf.runtime.diagram.ui.editparts.DiagramEditPart;
import org.eclipse.gmf.runtime.diagram.ui.services.editpolicy.CreateEditPoliciesOperation;
import org.eclipse.gmf.runtime.diagram.ui.services.editpolicy.IEditPolicyProvider;
import org.eclipse.gmf.runtime.notation.Diagram;
import org.eclipse.papyrus.infra.gmfdiag.common.utils.DiagramEditPartsUtil;
import org.eclipse.papyrusrt.umlrt.tooling.diagram.common.Activator;
import org.eclipse.papyrusrt.umlrt.tooling.diagram.common.utils.UMLRTCapsuleStructureDiagramUtils;
import org.eclipse.uml2.common.util.CacheAdapter;

import com.google.common.collect.ImmutableMap;

/**
 * An edit-policy provider that serves to replace stereotype-application edit-policies
 * by our own that account for inheritance of views from other diagrams.
 */
public class RTAppliedStereotypeEditPolicyProvider extends AbstractProvider implements IEditPolicyProvider {

	private final Map<String, Class<? extends EditPolicy>> editPolicies = ImmutableMap.of(
			APPLIED_STEREOTYPE_COMMENT, RTAppliedStereotypeCommentEditPolicy.class);

	@Override
	public boolean provides(IOperation operation) {
		Diagram diagram = getDiagramView(((CreateEditPoliciesOperation) operation).getEditPart());
		return (diagram != null) && isCapsuleStructureDiagram(diagram);
	}

	@Override
	public void createEditPolicies(EditPart editPart) {
		// Replace edit-policies with our variants
		editPolicies.forEach((role, epClass) -> {
			EditPolicy existing = editPart.getEditPolicy(role);
			if (existing != null) {
				try {
					editPart.installEditPolicy(role, epClass.newInstance());
				} catch (Exception e) {
					Activator.log.error("Failed to override edit policy: " + role, e); //$NON-NLS-1$
				}
			}
		});
	}

	Diagram getDiagramView(EditPart editPart) {
		DiagramEditPart diagramEP = DiagramEditPartsUtil.getDiagramEditPart(editPart);
		return (diagramEP == null) ? null : diagramEP.getDiagramView();
	}

	private boolean isCapsuleStructureDiagram(Diagram diagram) {
		CacheAdapter cache = CacheAdapter.getCacheAdapter(diagram);
		Boolean result = (Boolean) cache.get(diagram, "isCapsuleStructureDiagram"); //$NON-NLS-1$
		if (result == null) {
			result = UMLRTCapsuleStructureDiagramUtils.isCapsuleStructureDiagram(diagram);
			cache.put(diagram, "isCapsuleStructureDiagram", result);
		}

		return result;
	}
}

==> org.eclipse.papyrusrt.umlrt.tooling.diagram.common.source_0.9.0.201706220444.jar: org/eclipse/papyrusrt/umlrt/tooling/diagram/common/internal/editpolicies/stereotype/RTAppliedStereotypeEditPolicyProvider.java <==
/*****************************************************************************
 * Copyright (c) 2016, 2017 Christian W. Damus and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   Christian W. Damus - Initial API and implementation
 *   
 *****************************************************************************/

package org.eclipse.papyrusrt.umlrt.tooling.diagram.common.internal.editpolicies.stereotype;

import static org.eclipse.papyrus.uml.diagram.stereotype.edition.editpolicies.AppliedStereotypeCommentEditPolicy.APPLIED_STEREOTYPE_COMMENT;

import java.util.Map;

import org.eclipse.gef.EditPart;
import org.eclipse.gef.EditPolicy;
import org.eclipse.gmf.runtime.common.core.service.AbstractProvider;
import org.eclipse.gmf.runtime.common.core.service.IOperation;
import org.eclipse.gmf.runtime.diagram.ui.editparts.DiagramEditPart;
import org.eclipse.gmf.runtime.diagram.ui.services.editpolicy.CreateEditPoliciesOperation;
import org.eclipse.gmf.runtime.diagram.ui.services.editpolicy.IEditPolicyProvider;
import org.eclipse.gmf.runtime.notation.Diagram;
import org.eclipse.papyrus.infra.gmfdiag.common.utils.DiagramEditPartsUtil;
import org.eclipse.papyrusrt.umlrt.tooling.diagram.common.Activator;
import org.eclipse.papyrusrt.umlrt.tooling.diagram.common.utils.UMLRTCapsuleStructureDiagramUtils;
import org.eclipse.uml2.common.util.CacheAdapter;

import com.google.common.collect.ImmutableMap;

/**
 * An edit-policy provider that serves to replace stereotype-application edit-policies
 * by our own that account for inheritance of views from other diagrams.
 */
public class RTAppliedStereotypeEditPolicyProvider extends AbstractProvider implements IEditPolicyProvider {

	private final Map<String, Class<? extends EditPolicy>> editPolicies = ImmutableMap.of(
			APPLIED_STEREOTYPE_COMMENT, RTAppliedStereotypeCommentEditPolicy.class);

	@Override
	public boolean provides(IOperation operation) {
		Diagram diagram = getDiagramView(((CreateEditPoliciesOperation) operation).getEditPart());
		return (diagram != null) && isCapsuleStructureDiagram(diagram);
	}

	@Override
	public void createEditPolicies(EditPart editPart) {
		// Replace edit-policies with our variants
		editPolicies.forEach((role, epClass) -> {
			EditPolicy existing = editPart.getEditPolicy(role);
			if (existing != null) {
				try {
					editPart.installEditPolicy(role, epClass.newInstance());
				} catch (Exception e) {
					Activator.log.error("Failed to override edit policy: " + role, e); //$NON-NLS-1$
				}
			}
		});
	}

	Diagram getDiagramView(EditPart editPart) {
		DiagramEditPart diagramEP = DiagramEditPartsUtil.getDiagramEditPart(editPart);
		return (diagramEP == null) ? null : diagramEP.getDiagramView();
	}

	private boolean isCapsuleStructureDiagram(Diagram diagram) {
		CacheAdapter cache = CacheAdapter.getCacheAdapter(diagram);
		Boolean result = (cache == null)
				? null
				: (Boolean) cache.get(diagram, "isCapsuleStructureDiagram"); //$NON-NLS-1$
		if (result == null) {
			result = UMLRTCapsuleStructureDiagramUtils.isCapsuleStructureDiagram(diagram);
			if (cache != null) {
				cache.put(diagram, "isCapsuleStructureDiagram", result);
			}
		}

		return result;
	}
}
